@@ -8,6 +8,8 @@ from .comment import getComments, addCommentWithFile
 from .helpers import (getTime, createdAtFrom, createdAtTo,
                       handleDate, listToClass)
 from .metadata import addMetadataTo, getMetadata
+from .collection import (addToCollection, getAttachedCollections,
+                         removeFromCollection)
 
 
 def getExperiment(user, experiment_id):
@@ -31,7 +33,7 @@ def getExperiment(user, experiment_id):
 
 
 def getExperiments(user, count=100, search_query=None,
-                   created_at_from=None, created_at_to=None, tag_id=None,
+                   created_at_from=None, created_at_to=None, tag_id=None, collection_id=None,
                    extraParams={}):
     """
     Retrieve a list of a user's Experiments on Labstep,
@@ -45,7 +47,7 @@ def getExperiments(user, count=100, search_query=None,
     count (int)
         The number of Experiments to retrieve.
     search_query (str)
-        Search for Experiments with this 'name'.
+        Search for Experiments containing this string in the name or entry.
     created_at_from (str)
         The start date of the search range, must be
         in the format of 'YYYY-MM-DD'.
@@ -53,7 +55,9 @@ def getExperiments(user, count=100, search_query=None,
         The end date of the search range, must be
         in the format of 'YYYY-MM-DD'.
     tag_id (int)
-        The id of the Tag to retrieve.
+        Get experiments tagged with this tag.
+    collection_id (int)
+        Get experiments in this collection.
     extraParams (dict)
         Dictionary of extra filter parameters.
 
@@ -66,6 +70,7 @@ def getExperiments(user, count=100, search_query=None,
               'created_at_from': createdAtFrom(created_at_from),
               'created_at_to': createdAtTo(created_at_to),
               'tag_id': tag_id,
+              'folder_id': collection_id,
               **extraParams}
     return getEntities(user, Experiment, count, params)
 
@@ -1034,6 +1039,39 @@ class Experiment(PrimaryEntity):
 
         return newEntity(self.__user__, ExperimentMaterial, params)
 
+    def addToCollection(self, collection_id):
+        """
+        Add the experiment to a collection.
+
+        Parameters
+        ----------
+        collection_id (int)
+            The id of the collection to add to
+
+        Returns
+        -------
+        None
+        """
+        return addToCollection(self, collection_id=collection_id)
+
+    def getCollections(self):
+        """
+        Returns the list of collections the protocol is in.
+        """
+        return getAttachedCollections(self)
+
+    def removeFromCollection(self, collection_id):
+        """
+        Remove the experiment from a collection.
+
+        Parameters
+        ----------
+        collection_id (int)
+            The id of the collection to remove from
+
+        """
+        return removeFromCollection(self, collection_id)
+
     def addTable(self, name=None, data=None):
         """
         Add a new table to an Experiment.
